@@ -3,7 +3,6 @@ from datetime import datetime
 from sqlalchemy import (
     Column,
     Integer,
-    String,
     DateTime,
     ForeignKey,
 )
@@ -20,7 +19,11 @@ class InterventionNewswireModel(Base):
         ForeignKey('newswires.id'),
         nullable=False,
     )
-    norm_cui = Column(String(50), nullable=False, index=True)
+    intervention_id = Column(
+        Integer,
+        ForeignKey('interventions.id'),
+        nullable=False,
+    )
     updated_at = Column(
         DateTime,
         nullable=False,
