@@ -5,6 +5,7 @@ from sqlalchemy import (
     Integer,
     DateTime,
     String,
+    Text,
 )
 
 from ...database import Base
@@ -15,6 +16,7 @@ class InvestorModel(Base):
 
     id = Column(Integer, primary_key=True)
     name = Column(String(256), nullable=False)
+    aliases = Column(Text, nullable=True)
     website = Column(String(256), nullable=True)
     type = Column(String(50), nullable=True)
     updated_at = Column(
