@@ -17,10 +17,12 @@ class NCTStudyModel(Base):
     nct_id = Column(String(128), nullable=False, unique=True)
     brief_title = Column(Text)
     study_status = Column(String(128))
+    study_type = Column(String(50))
     study_start_date = Column(DateTime)
     last_update_submitted_qc_date = Column(DateTime)
     phase = Column(Text)
     sponsors = Column(Text)
+    conditions = Column(Text)
     industry_flag = Column(Boolean)
     updated_at = Column(
         DateTime,
